@@ -2,5 +2,12 @@
 A subpackage containing internal definitions and utilities to create the structure of the entire library.
 """
 from ._cache import cached_quantity, parameter
-from ._framework import Framework, Component
+from ._framework import (
+    Framework,
+    Component,
+    pluggable,
+    get_mdl,
+    get_base_component,
+    get_base_components,
+)
 from ._utils import inherit_docstrings
