@@ -8,6 +8,7 @@ updated.
 """
 from functools import update_wrapper
 from copy import deepcopy
+import warnings
 
 
 def hidden_loc(obj, name):
@@ -30,7 +31,7 @@ def cached_quantity(f):
     Examples
     --------
 
-    >>>   class CachedClass(object):
+    >>>   class CachedClass:
     >>>      @parameter
     >>>      def a_param(self,val):
     >>>         return val
@@ -72,7 +73,12 @@ def cached_quantity(f):
         # otherwise they will be lost to their parents.
         if name in recalc:
             for pr in activeq:
-                recalc_prpa[pr].update(recalc_prpa[name])
+                try:
+                    recalc_prpa[pr].update(recalc_prpa[name])
+                except KeyError:
+                    raise KeyError(
+                        f"When getting {name}, couldn't find {pr} in recalc_prpa. Had {list(recalc_prpa.keys())}."
+                    )
 
             # check all quantities for dependence on subframeworks and update their entries
             for s in subframeworks:
@@ -146,11 +152,19 @@ def cached_quantity(f):
         try:
             prop = hidden_loc(self, name)
             delattr(self, prop)
-            del getattr(self, recalc)[name]
-            del getattr(self, recalc_prpa)[name]
         except AttributeError:
             pass
 
+        try:
+            del getattr(self, recalc)[name]
+        except KeyError:
+            warnings.warn(f"{name} not found in recalc cache.")
+
+        try:
+            del getattr(self, recalc_prpa)[name]
+        except KeyError:
+            warnings.warn(f"{name} not found in recalc_prop_par cache")
+
     return property(_get_property, None, _del_property)
 
 
@@ -256,9 +270,8 @@ def parameter(kind):
                     setattr(self, prop, val)
 
                 # Make sure children are updated
-                if (
-                    kind != "switch" or doset
-                ):  # Normal parameters just update dependencies
+                if kind != "switch" or doset:
+                    # Normal parameters just update dependencies
                     for pr in getattr(self, recalc_papr)[name]:
                         getattr(self, recalc)[pr] = True
                 else:
