@@ -2,3 +2,6 @@
 A subpackage dedicated to descriptions of internal halo properties, such as their mass. See ``halomod`` for more
 extended quantities in this regard.
 """
+
+from . import mass_definitions
+from .mass_definitions import MassDefinition
